# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2017-11-01 07:49
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='EmailValidation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email', models.CharField(max_length=254)),
                ('key', models.CharField(max_length=255)),
                ('created_on', models.DateTimeField(auto_now_add=True)),
                ('updated_on', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.AlterModelOptions(
            name='account',
            options={'verbose_name': 'account', 'verbose_name_plural': 'accounts'},
        ),
        migrations.AddField(
            model_name='emailvalidation',
            name='account',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='email_validations', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddIndex(
            model_name='emailvalidation',
            index=models.Index(fields=['account', 'email'], name='account_email_idx'),
        ),
        migrations.AddIndex(
            model_name='emailvalidation',
            index=models.Index(fields=['key'], name='key_idx'),
        ),
    ]
